Index: src/ppc/macro-assembler-ppc.h |
diff --git a/src/ppc/macro-assembler-ppc.h b/src/ppc/macro-assembler-ppc.h |
index 6b7ef9402d6c5f4da66ad671d3635db2ee243d7b..06ddbfc7876605b6c3f063fcb498d12ca898c722 100644 |
--- a/src/ppc/macro-assembler-ppc.h |
+++ b/src/ppc/macro-assembler-ppc.h |
@@ -644,8 +644,8 @@ class MacroAssembler : public Assembler { |
void Allocate(int object_size, Register result, Register scratch1, |
Register scratch2, Label* gc_required, AllocationFlags flags); |
- void Allocate(Register object_size, Register result, Register scratch1, |
- Register scratch2, Label* gc_required, AllocationFlags flags); |
+ void Allocate(Register object_size, Register result, Register result_end, |
+ Register scratch, Label* gc_required, AllocationFlags flags); |
void AllocateTwoByteString(Register result, Register length, |
Register scratch1, Register scratch2, |
@@ -687,17 +687,17 @@ class MacroAssembler : public Assembler { |
void CopyBytes(Register src, Register dst, Register length, Register scratch); |
// Initialize fields with filler values. |count| fields starting at |
- // |start_offset| are overwritten with the value in |filler|. At the end the |
- // loop, |start_offset| points at the next uninitialized field. |count| is |
- // assumed to be non-zero. |
- void InitializeNFieldsWithFiller(Register start_offset, Register count, |
+ // |current_address| are overwritten with the value in |filler|. At the end |
+ // the loop, |current_address| points at the next uninitialized field. |
+ // |count| is assumed to be non-zero. |
+ void InitializeNFieldsWithFiller(Register current_address, Register count, |
Register filler); |
- // Initialize fields with filler values. Fields starting at |start_offset| |
- // not including end_offset are overwritten with the value in |filler|. At |
- // the end the loop, |start_offset| takes the value of |end_offset|. |
- void InitializeFieldsWithFiller(Register start_offset, Register end_offset, |
- Register filler); |
+ // Initialize fields with filler values. Fields starting at |current_address| |
+ // not including |end_address| are overwritten with the value in |filler|. At |
+ // the end the loop, |current_address| takes the value of |end_address|. |
+ void InitializeFieldsWithFiller(Register current_address, |
+ Register end_address, Register filler); |
// --------------------------------------------------------------------------- |
// Support functions. |